@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/child.c,v 1.22 2004/04/28 13:52:38 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/child.c,v 1.23 2004/05/06 06:28:41 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -187,8 +187,7 @@ void do_child(int unix_fd, int inet_fd)
 			if (pool_config.replication_enabled)
 				reset_backend(SECONDARY_CONNECTION(backend)->con);
 
-			/* send Auth OK and Ready for Query to the frontend */
-			if (pool_send_auth_ok(frontend, MASTER_CONNECTION(backend)->pid, MASTER_CONNECTION(backend)->key) != POOL_CONTINUE)
+			if (pool_do_reauth(frontend, backend))
 			{
 				pool_close(frontend);
 				continue;
@@ -219,7 +218,10 @@ void do_child(int unix_fd, int inet_fd)
 					/* do not cache connection to template0, template1, regression */
 					if (!strcmp(sp->database, "template0") || !strcmp(sp->database, "template1") ||
 						!strcmp(sp->database, "regression"))
+					{
+						pool_send_frontend_exits(backend);
 						pool_discard_cp(sp->user, sp->database);
+					}
 					else
 						pool_connection_pool_timer(backend);
 					break;
