@@ -1,7 +1,7 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.14 2004/04/14 00:28:27 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.15 2004/05/06 06:30:59 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -98,6 +98,8 @@ typedef struct {
 	int replication_enabled;		/* replication mode enabled */
 } POOL_CONFIG;
 
+#define MAX_PASSWORD_SIZE		1024
+
 /*
  * stream connection structure
  */
@@ -113,6 +115,15 @@ typedef struct {
 	int sbufsz;	/* it's size */
 	int isbackend;		/* this connection is for backend if non 0 */
 	int issecondary_backend;		/* this connection is for secondary backend if non 0 */
+
+	/*
+	 * following are used to remember when re-use the authenticated connection
+	 */
+	int auth_kind;		/* 3: clear text password, 4: crypt password, 5: md5 password */
+	int pwd_size;		/* password (sent back from frontend) size in host order */
+	char password[MAX_PASSWORD_SIZE];		/* /* password (sent back from frontend) */
+	char salt[4];		/* password salt */
+
 } POOL_CONNECTION;
 
 /*
@@ -195,9 +206,8 @@ extern char *pool_read_string(POOL_CONNECTION *cp, int *len, int line);
 
 extern POOL_CONNECTION_POOL *pool_get_cp(char *user, char *database);
 
-extern POOL_STATUS pool_do_auth(POOL_CONNECTION *frontend, 
-				POOL_CONNECTION_POOL *backend);
-extern POOL_STATUS pool_send_auth_ok(POOL_CONNECTION *frontend, int pid, int key);
+extern POOL_STATUS pool_do_auth(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend);
+extern POOL_STATUS pool_do_reauth(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp);
 
 extern int pool_init_cp(void);
 extern POOL_CONNECTION_POOL *pool_create_cp(char *user, char *database);
@@ -207,16 +217,18 @@ extern void pool_discard_cp(char *user, char *database);
 extern POOL_STATUS ErrorResponse(POOL_CONNECTION *frontend, 
 								  POOL_CONNECTION_POOL *backend);
 
-void notice_backend_error(void);
+extern void notice_backend_error(void);
 
-void pool_connection_pool_timer(POOL_CONNECTION_POOL *backend);
-RETSIGTYPE pool_backend_timer_handler(int sig);
+extern void pool_connection_pool_timer(POOL_CONNECTION_POOL *backend);
+extern RETSIGTYPE pool_backend_timer_handler(int sig);
 
-int connect_inet_domain_socket(int secondary_backend);
-int connect_unix_domain_socket(int secondary_backend);
+extern int connect_inet_domain_socket(int secondary_backend);
+extern int connect_unix_domain_socket(int secondary_backend);
 
-int pool_check_fd(POOL_CONNECTION *cp, int notimeout);
-void pool_enable_timeout(void);
-void pool_disable_timeout(void);
+extern int pool_check_fd(POOL_CONNECTION *cp, int notimeout);
+extern void pool_enable_timeout(void);
+extern void pool_disable_timeout(void);
+
+extern void pool_send_frontend_exits(POOL_CONNECTION_POOL *backend);
 
 #endif /* POOL_H */
