@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.13 2004/04/17 01:49:44 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.14 2004/05/06 06:37:55 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -1374,3 +1374,23 @@ static void process_reporting(POOL_CONNECTION *frontend)
 
 	pool_flush(frontend);
 }
+
+void pool_send_frontend_exits(POOL_CONNECTION_POOL *backend)
+{
+	pool_write(MASTER(backend), "X", 1);
+
+	/*
+	 * XXX we cannot call pool_flush() here since backend may already
+	 * close the socket and pool_flush() automatically invokes fail
+	 * over handler. This could happen in copy command (remember the
+	 * famouse "lostsynchronization with server, resettin g
+	 * connection" message)
+	 */
+	fflush(MASTER(backend)->write_fd);
+
+	if (REPLICATION)
+	{
+		pool_write(SECONDARY(backend), "X", 1);
+		fflush(SECONDARY(backend)->write_fd);
+	}
+}
